@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Log::Log4perl::Tiny qw< :easy :dead_if_first LOGLEVEL >;
-our $VERSION = '0.721001'; # TRIAL
+our $VERSION = '0.723'; # TRIAL
 
 use Data::Tubes::Util
   qw< normalize_args normalize_filename args_array_with_options >;
@@ -97,9 +97,9 @@ sub iterate_files {
          name    => 'files',
 
          # options specific for sub-tubes
-         iterate_array => {},
-         open_file     => {},
-         logger        => {
+         iterate_array_args => {},
+         open_file_args     => {},
+         logger_args        => {
             target => sub {
                my $record = shift;
                return 'reading from ' . $record->{source}{name},;
